@@ -203,7 +203,7 @@ SymmetryOps::SymmetryOps(GAMESSPointGroup pg, short pgOrder) {
 		if ((pg == GAMESS_CNH) || (pg == GAMESS_DNH)) {
 			//Add the sigma-H plane (z=0) by repeating the rotations
 			//and inverting the z coordinate
-			int count = operations.size()/9;
+			int count = (int) operations.size()/9;
 			for (int i=0; i<count; i++) {
 				operations.push_back(operations[9*i]);
 				operations.push_back(operations[9*i+1]);
@@ -219,7 +219,7 @@ SymmetryOps::SymmetryOps(GAMESSPointGroup pg, short pgOrder) {
 		}
 		if ((pg >= GAMESS_DND) && (pg <= GAMESS_DN)) {
 			//Dn, DnH and DnD have a two fold axis as the x axis
-			int count = operations.size()/9;
+			int count = (int) operations.size()/9;
 			for (int i=0; i<count; i++) {
 				operations.push_back(operations[9*i]);
 				operations.push_back(-operations[9*i+1]);
@@ -238,8 +238,8 @@ SymmetryOps::SymmetryOps(GAMESSPointGroup pg, short pgOrder) {
 				double cosb = cos(beta);
 				double sinb = sin(beta);
 				//replicate all the preceding operations with an x/y rotation
-				int count = operations.size()/9;
-				for (int i=0; i<count; i++) {
+				int operationcount = (int) operations.size()/9;
+				for (int i=0; i<operationcount; i++) {
 					operations.push_back(cosb*operations[9*i]+sinb*operations[9*i+1]);
 					operations.push_back(-(-sinb*operations[9*i]+cosb*operations[9*i+1]));
 					operations.push_back(operations[9*i+2]);
@@ -256,7 +256,7 @@ SymmetryOps::SymmetryOps(GAMESSPointGroup pg, short pgOrder) {
 		}
 		if (pg == GAMESS_CNV) {
 			//sigma V plane is XZ plane
-			int count = operations.size()/9;
+			int count = (int) operations.size()/9;
 			for (int i=0; i<count; i++) {
 				operations.push_back(operations[9*i]);
 				operations.push_back(-operations[9*i+1]);
@@ -286,7 +286,7 @@ SymmetryOps::SymmetryOps(GAMESSPointGroup pg, short pgOrder) {
 		double beta = pi2/(2.0*((double) pgOrder));
 		double cosb = cos(beta);
 		double sinb = sin(beta);
-		int count = operations.size()/9;
+		int count = (int) operations.size()/9;
 		for (int i=0; i<count; i++) {
 			operations.push_back(cosb*operations[9*i]+sinb*operations[9*i+1]);
 			operations.push_back(-sinb*operations[9*i]+cosb*operations[9*i+1]);
@@ -323,7 +323,7 @@ SymmetryOps::SymmetryOps(GAMESSPointGroup pg, short pgOrder) {
 		//Done with T continue on for others
 		if (pg == GAMESS_TH) {
 			//TH is finished off with a direct product with CI
-			int count = operations.size();
+			int count = (int) operations.size();
 			for (int i=0; i<count; i++) {
 				operations.push_back( - operations[i]);
 			}
@@ -345,7 +345,7 @@ SymmetryOps::SymmetryOps(GAMESSPointGroup pg, short pgOrder) {
 			}
 			if (pg == GAMESS_OH) {
 				//OH is a direct product of O and CI
-				int count = operations.size();
+				int count = (int) operations.size();
 				for (int i=0; i<count; i++) {
 					operations.push_back( - operations[i]);
 				}
@@ -468,6 +468,12 @@ Orb2DSurface::Orb2DSurface(XMLElement * sxml) {
 				case MMP_OrbSurfBase:
 					OrbSurfBase::ReadXML(child);
 					break;
+				default:
+				{
+					wxString msg;
+					msg.Printf(_T("Unknown CML element in parsing Orb2DSurface: %s"), child->getName());
+					wxLogMessage(msg);
+				}
 			}
 		}
 		child = child->getNextChild();
@@ -492,6 +498,13 @@ Orb3DSurface::Orb3DSurface(XMLElement * sxml) {
 				case MMP_OrbSurfBase:
 					OrbSurfBase::ReadXML(child);
 					break;
+				default:
+				{
+					wxString msg;
+					msg.Printf(_T("Unknown CML element in Orb3DSurface::Orb3DSurface: %s"), child->getName());
+					wxLogMessage(msg);
+				}
+					break;
 			}
 		}
 		child = child->getNextChild();
@@ -512,6 +525,13 @@ General2DSurface::General2DSurface(XMLElement * sxml) {
 				case MMP_2DSurface:
 					Surf2DBase::Read2DXML(child);
 					break;
+				default:
+				{
+					wxString msg;
+					msg.Printf(_T("Unknown CML element in General2DSurface::General2DSurface: %s"), child->getName());
+					wxLogMessage(msg);
+				}
+					break;
 			}
 		}
 		child = child->getNextChild();
@@ -533,6 +553,13 @@ General3DSurface::General3DSurface(XMLElement * sxml) {
 				case MMP_3DSurface:
 					Surf3DBase::Read3DXML(child);
 					break;
+				default:
+				{
+					wxString msg;
+					msg.Printf(_T("Unknown CML element in General3DSurface::General3DSurface: %s"), child->getName());
+					wxLogMessage(msg);
+				}
+					break;
 			}
 		}
 		child = child->getNextChild();
@@ -566,6 +593,14 @@ TEDensity1DSurface::TEDensity1DSurface(XMLElement * sxml) {
 					if (child->getLongValue(tl))
 						OrbSet = tl;
 				}
+					break;
+				default:
+				{
+					wxString msg;
+					msg.Printf(_T("Unknown CML element in TEDensity1DSurface::TEDensity1DSurface: %s"), child->getName());
+					wxLogMessage(msg);
+				}
+					break;
 			}
 		}
 		child = child->getNextChild();
@@ -599,6 +634,14 @@ TEDensity2DSurface::TEDensity2DSurface(XMLElement * sxml) {
 					if (child->getLongValue(tl))
 						OrbSet = tl;
 				}
+					break;
+				default:
+				{
+					wxString msg;
+					msg.Printf(_T("Unknown CML element in TEDensity2DSurface::TEDensity2DSurface: %s"), child->getName());
+					wxLogMessage(msg);
+				}
+					break;
 			}
 		}
 		child = child->getNextChild();
@@ -643,6 +686,13 @@ TEDensity3DSurface::TEDensity3DSurface(XMLElement * sxml) {
 						OrbSet = tl;
 				}
 					break;
+				default:
+				{
+					wxString msg;
+					msg.Printf(_T("Unknown CML element in TEDensity3DSurface::TEDensity3DSurface: %s"), child->getName());
+					wxLogMessage(msg);
+				}
+					break;
 			}
 		}
 		child = child->getNextChild();
@@ -674,6 +724,14 @@ MEP2DSurface::MEP2DSurface(XMLElement * sxml) {
 					if (child->getLongValue(tl))
 						OrbSet = tl;
 				}
+					break;
+				default:
+				{
+					wxString msg;
+					msg.Printf(_T("Unknown CML element in MEP2DSurface::MEP2DSurface: %s"), child->getName());
+					wxLogMessage(msg);
+				}
+					break;
 			}
 		}
 		child = child->getNextChild();
@@ -706,6 +764,13 @@ MEP3DSurface::MEP3DSurface(XMLElement * sxml) {
 						OrbSet = tl;
 				}
 					break;
+				default:
+				{
+					wxString msg;
+					msg.Printf(_T("Unknown CML element in MEP3DSurface::MEP3DSurface: %s"), child->getName());
+					wxLogMessage(msg);
+				}
+					break;
 			}
 		}
 		child = child->getNextChild();
@@ -837,6 +902,13 @@ void Surf1DBase::Read1DXML(XMLElement *parent) {
 						if (test != count) FreeGrid();
 					}
 					break;
+				default:
+				{
+					wxString msg;
+					msg.Printf(_T("Unknown CML element in Surf1DBase::Read1DXML: %s"), child->getName());
+					wxLogMessage(msg);
+				}
+					break;
 			}
 		}
 		child = child->getNextChild();
@@ -1015,6 +1087,13 @@ void Surf2DBase::Read2DXML(XMLElement * parent) {
 						if (test != count) FreeGrid();
 					}
 					break;
+				default:
+				{
+					wxString msg;
+					msg.Printf(_T("Unknown CML element in Surf2DBase::Read2DXML: %s"), child->getName());
+					wxLogMessage(msg);
+				}
+					break;
 			}
 		}
 		child = child->getNextChild();
@@ -1293,6 +1372,13 @@ void Surf3DBase::Read3DXML(XMLElement * parent) {
 						if (test != NumVertices) FreeList();
 					}
 					break;
+				default:
+				{
+					wxString msg;
+					msg.Printf(_T("Unknown CML element in Surf3DBase::Read3DXML: %s"), child->getName());
+					wxLogMessage(msg);
+				}
+					break;
 			}
 		}
 		child = child->getNextChild();
@@ -1353,6 +1439,13 @@ void OrbSurfBase::ReadXML(XMLElement * parent) {
 					if (child->getBoolValue(tb))
 						SetOrbOccDisplay(tb);
 					break;
+				default:
+				{
+					wxString msg;
+					msg.Printf(_T("Unknown CML element in OrbSurfBase::ReadXML: %s"), child->getName());
+					wxLogMessage(msg);
+				}
+					break;
 			}
 		}
 		child = child->getNextChild();
@@ -1389,6 +1482,13 @@ bool Surface::ReadXML(XMLElement * parent) {
 					if (c) SetLabel(c);
 				}
 					break;
+				default:
+				{
+					wxString msg;
+					msg.Printf(_T("Unknown CML element in Surface::ReadXML: %s"), child->getName());
+					wxLogMessage(msg);
+				}
+					break;
 			}
 		}
 		child = child->getNextChild();
@@ -1432,6 +1532,13 @@ Surface * Surface::ReadSurface(XMLElement * parent) {
 					case kGeneral2DSurface:
 						result = new General2DSurface(parent);
 						break;
+					default:
+					{
+						wxString msg;
+						msg.Printf(_T("Unknown CML surface element in Surface::ReadSurface: %s"), surftype);
+						wxLogMessage(msg);
+					}
+						break;
 				}
 			}
 		}
